@@ -199,7 +199,13 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 				if (!strcmp (cur->name, "component")) {
 					comp = g_new0 (BugzillaComponent, 1);
 					comp->product = prod;
-				
+					
+					/* This is a workaround for bad generated products.xml
+					   We really need to strict validation on bugzilla side
+					   or rewrote the script generating products.xml*/
+					if (!xmlGetProp (cur, "value"))
+						continue;
+	
 					comp->name        = XML_NODE_GET_PROP (cur, "value");
 					comp->description = XML_NODE_GET_PROP (cur, "description");
 
@@ -1463,7 +1469,7 @@ generate_email_text (gboolean include_headers)
 	email = g_string_new (NULL);
 
 	subject    = buddy_get_text ("desc-subject");
-	version    = druid_data.version ? druid_data.version : "unspecified";
+	version    = druid_data.version ? druid_data.version : strdup("unspecified");
 
 	s          = buddy_get_text ("desc-text");
 	body = format_for_width (s);
